@@ -144,13 +144,13 @@ class ImplicitEndpoint:
 
         if "returns" in func_doc:
             retStr = "<ul><li>"
-            if "type" in func_doc["return"]:
+            if "type" in func_doc["returns"]:
                 retStr += "<b><i>" + \
-                    func_doc["return"]["type"] + \
+                    func_doc["returns"]["type_name"] + \
                     "</i></b>"
-            if "summary" in func_doc["return"]:
+            if "summary" in func_doc["returns"]:
                 "<p>" + \
-                    func_doc["return"]["summary"] + \
+                    func_doc["returns"]["summary"] + \
                     "</p>"
             retStr += "</li></ul>"
             ret += retStr.replace("\n", "<br />")
